==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/CategorySeriesInteractionManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, typeCast, markType } from "igniteui-react-core";
import { ICategorySeriesInteractionManager_$type } from "./ICategorySeriesInteractionManager";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { HighlightingInfo } from "./HighlightingInfo";
import { intDivide, truncate, isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let CategorySeriesInteractionManager = /*@__PURE__*/ (() => {
    class CategorySeriesInteractionManager extends Base {
        b$c(a, b) {
            let c = a.cj.by;
            let d = a.cj.bx;
            let e = a.as();
            let f = a.getEffectiveViewport1(a.cj);
            let g = a.to(a.cj);
            let h = -1;
            if (e != null && !c.isEmpty && !d.isEmpty) {
                let i = new ScalerParams(0, c, d, e.ch, f);
                let j = e.em(g.left, i);
                let k = e.em(g.right, i);
                let l = (b.x - c.left) / c.width;
                let m = j + (l * (k - j));
                if (e.categoryMode != 0) {
                    m -= 0.5;
                }
                h = m;
            }
            return h;
        }
        b$f(a, b) {
            let c = 0;
            if (a.e5) {
                c = a.ja(b);
                if (c == -1) {
                    return null;
                }
            }
            else if (b.x == 1 && a.c6 != null) {
                c = a.c6.count - 1;
            }
            else {
                c = a.i8(b);
            }
            return c >= 0 && a.c6 != null && c < a.c6.count ? a.c6.item(c) : null;
        }
        b$d(a, b) {
            let c = a.cj.by;
            let d = a.cj.bx;
            let e = a.getEffectiveViewport1(a.cj);
            if (c.isEmpty || d.isEmpty) {
                return -1;
            }
            if (isNaN_(b.x)) {
                return -1;
            }
            let f = a.as();
            if (f == null) {
                return -1;
            }
            let g = typeCast(ISortingAxis_$type, f);
            let h = a.to(a.cj);
            let i = new ScalerParams(0, c, d, f.ch, e);
            let j = 0;
            if (f.cl) {
                let k = (b.x - c.left) / c.width;
                let l = k * h.width + h.left;
                j = f.em(l, i);
            }
            else {
                let m = f.em(h.left, i);
                let n = f.em(h.right, i);
                let o = (b.x - c.left) / c.width;
                j = m + ((n - m) * o);
            }
            let p = g.i$f(j);
            return p;
        }
        b$e(a, b, c) {
            let d = a.cj.bx;
            let e = a.cj.by;
            let f = a.as();
            let g = 0;
            if (f.cp) {
                let h = (c.y - e.top) / e.height;
                g = h * d.height + d.top;
            }
            else {
                let i = (c.x - e.left) / e.width;
                g = i * d.width + d.left;
            }
            if (f.ch) {
                let j = b.count;
                let k = 0;
                for (k = j - 1; k >= 0; k--) {
                    let l = b._inner[k];
                    let m = null;
                    if (k > 0) {
                        m = b._inner[k - 1];
                    }
                    if (l[0] <= g && m == null || m[0] >= g) {
                        if (m != null) {
                            if (Math.abs(l[0] - g) < Math.abs(m[0] - g)) {
                                return k;
                            }
                            else {
                                return k - 1;
                            }
                        }
                        else {
                            return k;
                        }
                    }
                }
                return k;
            }
            else {
                let n = b.count;
                let o = 0;
                for (o = 0; o < n; o++) {
                    let p = b._inner[o];
                    let q = null;
                    if (o < n - 1) {
                        q = b._inner[o + 1];
                    }
                    if (p[0] <= g && q == null || q[0] >= g) {
                        if (q != null) {
                            if (Math.abs(p[0] - g) < Math.abs(q[0] - g)) {
                                return o;
                            }
                            else {
                                return o + 1;
                            }
                        }
                        else {
                            return o;
                        }
                    }
                }
                return o;
            }
        }
        b$a(a, b, c, d, e, f, g, h) {
            if (a.c6 == null) {
                return null;
            }
            if (e == 0) {
                return null;
            }
            let i = a.c6.count;
            let j = a.as();
            let k = -1;
            let l = -1;
            if (j.cn) {
                let m = this.b$e(a, b, g);
                k = m;
                l = m;
            }
            else {
                let n = a.i8(g);
                k = truncate(Math.floor((intDivide(n, e)))) * e;
                l = k + (e - 1);
            }
            if (h != null && h.h == k && h.g == l) {
                return h;
            }
            let o = new HighlightingInfo();
            o.b = a;
            o.h = k;
            o.g = l;
            return o;
        }
        b$b(a, b, c, d, e, f, g, h) {
            if (a.c6 == null) {
                return null;
            }
            if (d == 0) {
                return null;
            }
            if (e == null || e.count == 0) {
                return null;
            }
            let i = a.c6.count;
            let j = a.as();
            let k = -1;
            let l = -1;
            let m = -1;
            if (j.cn) {
                let n = this.b$e(a, e, g);
                m = n;
                k = n;
                l = n;
            }
            else {
                let o = a.i8(g);
                m = truncate(Math.floor((intDivide(o, d)))) - c;
                k = m;
                l = m;
            }
            if (h != null && h.h == k && h.g == l) {
                return h;
            }
            let p = b;
            let q = p.count;
            if (p == null) {
                return null;
            }
            if (q == 0) {
                return null;
            }
            for (let r = 0; r < q; r++) {
                if (p._inner[r].al == m) {
                    let s = new HighlightingInfo();
                    s.b = a;
                    s.h = p._inner[r].al;
                    s.g = p._inner[r].al;
                    s.e = true;
                    return s;
                }
            }
            let t = a.tc(g);
            let u = p._inner[0].al;
            if (a.isVertical) {
                let v = e._inner[p._inner[0].al][0];
                let w = (t.y - v) * (t.y - v);
                let x;
                for (let y = 0; y < q; y++) {
                    v = e._inner[p._inner[y].al][0];
                    x = (t.y - v) * (t.y - v);
                    if (x <= w) {
                        w = x;
                        u = p._inner[y].al;
                    }
                }
            }
            else {
                let z = e._inner[p._inner[0].al][0];
                let aa = (t.x - z) * (t.x - z);
                let ab;
                for (let ac = 0; ac < q; ac++) {
                    z = e._inner[p._inner[ac].al][0];
                    ab = (t.x - z) * (t.x - z);
                    if (ab <= aa) {
                        aa = ab;
                        u = p._inner[ac].al;
                    }
                }
            }
            let ad = new HighlightingInfo();
            ad.b = a;
            ad.e = true;
            ad.h = u;
            ad.g = ad.h;
            if (h != null && h.h == ad.h && h.g == ad.g) {
                return h;
            }
            return ad;
        }
    }
    CategorySeriesInteractionManager.$t = /*@__PURE__*/ markType(CategorySeriesInteractionManager, 'CategorySeriesInteractionManager', Base.$, [ICategorySeriesInteractionManager_$type]);
    return CategorySeriesInteractionManager;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/CategorySeriesInteractionManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, typeCast, markType } from "igniteui-react-core";
import { ICategorySeriesInteractionManager_$type } from "./ICategorySeriesInteractionManager";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { HighlightingInfo } from "igniteui-react-core";
import { truncate, intDivide, isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let CategorySeriesInteractionManager = /*@__PURE__*/ (() => {
    class CategorySeriesInteractionManager extends Base {
        b$c(a, b) {
            let c = a.cu.by;
            let d = a.cu.bx;
            let e = a.a0();
            let f = a.getEffectiveViewport1(a.cu);
            let g = a.wf(a.cu);
            let h = -1;
            if (e != null && !c.isEmpty && !d.isEmpty) {
                let i = new ScalerParams(0, c, d, e.ch, f);
                let j = e.en(g.left, i);
                let k = e.en(g.right, i);
                let l = (b.x - c.left) / c.width;
                let m = j + (l * (k - j));
                if (e.categoryMode != 0) {
                    m -= 0.5;
                }
                h = m;
            }
            return h;
        }
        b$f(a, b) {
            let c = 0;
            if (a.fr) {
                c = a.j4(b);
                if (c == -1) {
                    return null;
                }
            }
            else if (b.x == 1 && a.dm != null) {
                c = a.dm.count - 1;
            }
            else {
                c = a.j2(b);
            }
            return c >= 0 && a.dm != null && c < a.dm.count ? a.dm.item(c) : null;
        }
        b$d(a, b) {
            let c = a.cu.by;
            let d = a.cu.bx;
            let e = a.getEffectiveViewport1(a.cu);
            if (c.isEmpty || d.isEmpty) {
                return -1;
            }
            if (isNaN_(b.x)) {
                return -1;
            }
            let f = a.a0();
            if (f == null) {
                return -1;
            }
            let g = typeCast(ISortingAxis_$type, f);
            let h = a.wf(a.cu);
            let i = new ScalerParams(0, c, d, f.ch, e);
            let j = 0;
            if (f.cl) {
                let k = (b.x - c.left) / c.width;
                let l = k * h.width + h.left;
                j = f.en(l, i);
            }
            else {
                let m = f.en(h.left, i);
                let n = f.en(h.right, i);
                let o = (b.x - c.left) / c.width;
                j = m + ((n - m) * o);
            }
            let p = g.i$f(j);
            return p;
        }
        b$e(a, b, c) {
            let d = a.cu.bx;
            let e = a.cu.by;
            let f = a.a0();
            let g = 0;
            if (f.cp) {
                let h = (c.y - e.top) / e.height;
                g = h * d.height + d.top;
            }
            else {
                let i = (c.x - e.left) / e.width;
                g = i * d.width + d.left;
            }
            if (f.ch) {
                let j = b.count;
                let k = 0;
                for (k = j - 1; k >= 0; k--) {
                    let l = b._inner[k];
                    let m = null;
                    if (k > 0) {
                        m = b._inner[k - 1];
                    }
                    if (l[0] <= g && m == null || m[0] >= g) {
                        if (m != null) {
                            if (Math.abs(l[0] - g) < Math.abs(m[0] - g)) {
                                return k;
                            }
                            else {
                                return k - 1;
                            }
                        }
                        else {
                            return k;
                        }
                    }
                }
                return k;
            }
            else {
                let n = b.count;
                let o = 0;
                for (o = 0; o < n; o++) {
                    let p = b._inner[o];
                    let q = null;
                    if (o < n - 1) {
                        q = b._inner[o + 1];
                    }
                    if (p[0] <= g && q == null || q[0] >= g) {
                        if (q != null) {
                            if (Math.abs(p[0] - g) < Math.abs(q[0] - g)) {
                                return o;
                            }
                            else {
                                return o + 1;
                            }
                        }
                        else {
                            return o;
                        }
                    }
                }
                return o;
            }
        }
        b$a(a, b, c, d, e, f, g, h, i) {
            if (a.dm == null) {
                return null;
            }
            if (f == 0) {
                return null;
            }
            let j = a.dm.count;
            let k = a.a0();
            let l = -1;
            let m = -1;
            if (k.cn) {
                let n = this.b$e(a, b, h);
                if (c != null && n >= 0 && n < c.count) {
                    n = truncate(Math.round(c._inner[n]));
                }
                l = n;
                m = n;
            }
            else {
                let o = a.j2(h);
                l = truncate(Math.floor((intDivide(o, f)))) * f;
                m = l + (f - 1);
            }
            if (i != null && i.g == l && i.f == m) {
                return i;
            }
            let p = new HighlightingInfo();
            p.i = a;
            p.g = l;
            p.f = m;
            return p;
        }
        b$b(a, b, c, d, e, f, g, h) {
            if (a.dm == null) {
                return null;
            }
            if (d == 0) {
                return null;
            }
            if (e == null || e.count == 0) {
                return null;
            }
            let i = a.dm.count;
            let j = a.a0();
            let k = -1;
            let l = -1;
            let m = -1;
            let n = -1;
            if (j.cn) {
                n = this.b$e(a, e, g);
                m = n;
                k = n;
                l = n;
            }
            else {
                let o = a.j2(g);
                m = o;
                n = truncate(Math.floor((intDivide(o, d)))) - c;
                k = n;
                l = n;
            }
            if (h != null && h.g == k && h.f == l) {
                return h;
            }
            let p = b;
            let q = p.count;
            if (p == null) {
                return null;
            }
            if (q == 0) {
                return null;
            }
            for (let r = 0; r < q; r++) {
                if (p._inner[r].al == n || p._inner[r].ak == m) {
                    let s = new HighlightingInfo();
                    s.i = a;
                    s.g = p._inner[r].ak;
                    s.f = p._inner[r].ak;
                    if (h != null && h.g == s.g && h.f == s.f) {
                        return h;
                    }
                    s.d = true;
                    return s;
                }
            }
            let t = a.v3(g);
            let u = p._inner[0].ak;
            if (a.isVertical) {
                let v = e._inner[p._inner[0].al][0];
                let w = (t.y - v) * (t.y - v);
                let x;
                for (let y = 0; y < q; y++) {
                    v = e._inner[p._inner[y].al][0];
                    x = (t.y - v) * (t.y - v);
                    if (x <= w) {
                        w = x;
                        u = p._inner[y].ak;
                    }
                }
            }
            else {
                let z = e._inner[p._inner[0].al][0];
                let aa = (t.x - z) * (t.x - z);
                let ab;
                for (let ac = 0; ac < q; ac++) {
                    z = e._inner[p._inner[ac].al][0];
                    ab = (t.x - z) * (t.x - z);
                    if (ab <= aa) {
                        aa = ab;
                        u = p._inner[ac].ak;
                    }
                }
            }
            let ad = new HighlightingInfo();
            ad.i = a;
            ad.d = true;
            ad.g = u;
            ad.f = ad.g;
            if (h != null && h.g == ad.g && h.f == ad.f) {
                return h;
            }
            return ad;
        }
    }
    CategorySeriesInteractionManager.$t = /*@__PURE__*/ markType(CategorySeriesInteractionManager, 'CategorySeriesInteractionManager', Base.$, [ICategorySeriesInteractionManager_$type]);
    return CategorySeriesInteractionManager;
})();
